@@ -3,6 +3,7 @@ import logging
 from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField
 from django.utils import timezone
 
+from isc_common import setAttr
 from isc_common.managers.common_manager import CommonManager, CommonQuerySet
 
 logger = logging.getLogger(__name__)
@@ -13,6 +14,18 @@ class AuditQuerySet(CommonQuerySet):
         self.alive_only = alive_only
         super().__init__(model=model, query=query, using=using, hints=hints, alive_only=alive_only)
 
+    def rearrange_parent(self, json):
+        _criteria = json.get('data').get('criteria')
+        if isinstance(_criteria, list):
+            for criterion in _criteria:
+                if criterion.get('fieldName') == 'parent_id':
+                    item_id = criterion.get('value')
+                    if (item_id, int):
+                        criteria_lst = [criterion for criterion in _criteria if criterion.get('fieldName') == 'parent_id' and criterion.get('value') != None]
+                        if len(criteria_lst) > 0:
+                            setAttr(json.get('data'), 'criteria', criteria_lst)
+        return json
+
     def soft_delete(self, visibleMode="hide"):
         res = 0
         if visibleMode == "hide":
