@@ -7,7 +7,7 @@ from isc_common import setAttr
 
 def DecimalToStr(value):
     if value == None:
-        return value
+        return ''
 
     try:
         res = str(value)
@@ -50,6 +50,37 @@ def IntToNumber(s):
 
     return float(s)
 
+def ToNumber(s):
+    if s == None:
+        return 0
+
+    if isinstance(s, int):
+        return IntToNumber(s)
+    elif isinstance(s, str):
+        return StrToNumber(s)
+    elif isinstance(s, float):
+        return s
+    elif isinstance(s, Decimal):
+        return float(s)
+    else:
+        raise Exception(f'{s} unknown type.')
+
+def ToDecimal(s):
+    if s == None:
+        return 0
+
+    if isinstance(s, int):
+        return Decimal(s)
+    elif isinstance(s, str):
+        return Decimal(s)
+    elif isinstance(s, float):
+        return Decimal(s)
+    elif isinstance(s, Decimal):
+        return s
+    else:
+        raise Exception(f'{s} unknown type.')
+
+
 def IntToDecimal(s):
     if s == None:
         return None
